pm4py.evaluation.wf\_net.variants package
=========================================

Submodules
----------

pm4py.evaluation.wf\_net.variants.petri\_net module
---------------------------------------------------

.. automodule:: pm4py.evaluation.wf_net.variants.petri_net
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.wf_net.variants
   :members:
   :undoc-members:
   :show-inheritance:
